@@ -87,10 +87,12 @@ config = {
 			"sentgram": { "type": "text", "analyzer": "postag_ana","fielddata":"true"}, # simple_complex_headpp compound_question_itis_svo
 			"np": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"ske": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
-			"i": { "type": "integer"},
-			"start": { "type": "integer"},
-			"end": { "type": "integer"},
+			"i": { "type": "integer", "index": "false"},
+			"start": { "type": "integer", "index": "false"},
+			"end": { "type": "integer", "index": "false"},
+			"head": { "type": "integer", "index": "false"},
 			"score": { "type": "float"},
+			"ratio": { "type": "float", "index": "false"},
 			"offset": { "type": "float"},
 			"final_score": { "type": "float"},
 			"sid": { "type": "keyword"},
@@ -115,6 +117,8 @@ config = {
 			"pos": { "type": "keyword"},
 			"tag": { "type": "keyword"},
 			"term": { "type": "keyword"},
+			"gpos": { "type": "keyword"},
+			"glem": { "type": "keyword"},
 
 			"ap": { "type": "keyword"},
 			"page": { "type": "keyword"},
